==> 0.0.37.tar.gz: lib/widget/custom/custom_text_form_field.dart <==
import 'package:sharing/widget/custom/spaces.dart';

import '../../common/values/borders.dart';
import '../../common/values/colors.dart';
import '../../common/values/sizes.dart';
import '../../common/values/styles.dart';
import 'custom_icon.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

// ignore: must_be_immutable
class CustomTextFormField extends StatefulWidget {
  final TextEditingController controller;
  final FocusNode focusNode;
  final FocusNode? focusNodeNext;
  final TextInputAction textInputAction;
  final TextStyle? hintTextStyle;
  final TextStyle? titleStyle;
  final TextStyle? contentStyle;
  final IconData? prefixIcon;
  final Widget? clearIcon;
  final Widget? prefixIconCustom;
  final Widget? suffixIcon;
  final String? hintText;
  final String? labelText;
  final String? title;
  final bool isPassword;
  final bool hasPrefixIcon;
  final bool hasSuffixIcon;
  final bool hasClearIcon;
  final bool hasTitle;
  final bool hasTitleIcon;
  final Widget? titleIcon;
  final TextInputType textInputType;
  final ValueChanged<String> onChange;
  final Function(String)? onSubmit;
  final FormFieldValidator<String>? validator;
  final List<TextInputFormatter>? inputFormatters;
  final double? width;
  final double? height;
  final EdgeInsetsGeometry? contentPadding;
  final EdgeInsetsGeometry? textFormFieldMargin;
  final Color? backgroundColor;
  final int maxLine;
  final bool hasEmpty;
  final AutovalidateMode autovalidate;
  final bool isBoxShadow;
  final String? textValue;
  final bool? isEnable;
  final int? maxLenght;
  bool isPasswordVisible;
  final GestureTapCallback? onSuffixIconTap;
  final GestureTapCallback? onClearIconTap;

  CustomTextFormField(
      {required this.controller,
      required this.focusNode,
      required this.onChange,
      this.focusNodeNext,
      this.onClearIconTap,
      this.clearIcon,
      this.hasClearIcon = false,
      this.onSubmit,
      this.maxLine = 1,
      this.prefixIcon,
      this.suffixIcon,
      this.hintTextStyle,
      this.titleStyle,
      this.contentStyle,
      this.titleIcon,
      this.hasTitleIcon = false,
      this.title,
      this.contentPadding,
      this.textFormFieldMargin,
      this.hasTitle = false,
      this.hintText,
      this.labelText,
      this.hasPrefixIcon = false,
      this.hasSuffixIcon = false,
      this.isPassword = false,
      this.textInputType = TextInputType.phone,
      this.validator,
      this.inputFormatters,
      this.width,
      this.height,
      this.backgroundColor,
      this.textInputAction = TextInputAction.done,
      this.hasEmpty = false,
      this.isBoxShadow = false,
      this.textValue,
      this.autovalidate = AutovalidateMode.onUserInteraction,
      this.isEnable = true,
      this.maxLenght = 100,
      this.isPasswordVisible = false,
      this.prefixIconCustom,
      this.onSuffixIconTap});

  @override
  State<CustomTextFormField> createState() => _CustomTextFormFieldState();
}

class _CustomTextFormFieldState extends State<CustomTextFormField> {
  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      mainAxisAlignment: MainAxisAlignment.center,
      mainAxisSize: MainAxisSize.max,
      children: <Widget>[
        Row(
          mainAxisSize: MainAxisSize.max,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: <Widget>[
            if (widget.hasTitleIcon) widget.titleIcon! else Container(),
            widget.hasTitle
                ? Text(widget.title!, style: widget.titleStyle)
                : Container(),
          ],
        ),
        Container(
          width: widget.width,
          height: widget.height,
          decoration: BoxDecoration(
            color: Colors.white,
            borderRadius: BorderRadius.circular(Sizes.RADIUS_10),
            boxShadow: showBoxShadow,
          ),
          margin: widget.textFormFieldMargin,
          child: TextFormField(
            showCursor: true,
            textInputAction: widget.textInputAction,
            textAlignVertical: TextAlignVertical.bottom,
            obscureText: isCheckObscureText(),
            maxLength: widget.maxLenght,
            enabled: widget.isEnable,
            controller: widget.controller,
            focusNode: widget.focusNode,
            style: widget.contentStyle ?? Styles.customTextMediumStyle(),
            keyboardType: widget.textInputType,
            onChanged: widget.onChange,
            onFieldSubmitted: (value) {
              if (widget.textInputAction == TextInputAction.next) {
                if (widget.focusNodeNext != null) {
                  FocusScope.of(context).requestFocus(widget.focusNodeNext);
                }
              }
              if (widget.onSubmit != null) {
                widget.onSubmit!(value);
              }
            },
            autovalidateMode: widget.autovalidate,
            validator: widget.validator,
            maxLines: widget.maxLine,
            inputFormatters: widget.inputFormatters,
            decoration: InputDecoration(
              contentPadding: EdgeInsets.only(
                  left: Sizes.PADDING_16,
                  top: Sizes.PADDING_16,
                  bottom: Sizes.PADDING_16,
                  right: -4),
              errorStyle:
                  TextStyle(color: Colors.red, fontSize: Sizes.TEXT_SIZE_16),
              labelText: widget.labelText,
              labelStyle: Styles.customTextDefaultStyle(
                      color: SharingColors.textColor1),
              border: Borders.customOutlineInputBorder(
                  borderRadius: Sizes.RADIUS_8),
              fillColor: widget.backgroundColor,
              filled: true,
              enabledBorder: Borders.customOutlineInputBorder(
                  borderRadius: Sizes.RADIUS_8),
              focusedBorder: Borders.customOutlineInputBorder(
                borderRadius: Sizes.RADIUS_8,
                color: SharingColors.secondaryColor,
                width: Sizes.WIDTH_2,
              ),
              prefixIcon: widget.hasPrefixIcon ? showPrefixIcon(context) : null,
              suffixIcon: showSuffixIcon(context),
              hintText: widget.hintText,
              hintStyle: widget.hintTextStyle,
              counterText: widget.textInputType == TextInputType.multiline ? null : "",
            ),
          ),
        ),
      ],
    );
  }

  bool isCheckObscureText() {
    if (widget.isPassword == true) {
      return !widget.isPasswordVisible;
    } else {
      return false;
    }
  }

  List<BoxShadow>? get showBoxShadow {
    if (widget.isBoxShadow) {
      return [
        BoxShadow(
          offset: Offset(0, 2),
          blurRadius: 8.0,
          color: Colors.black.withOpacity(0.2),
        ),
      ];
    } else {
      return null;
    }
  }

  Widget? showPrefixIcon(BuildContext context) {
    return widget.prefixIconCustom == null
        ? IconButton(
            icon: CustomIcon(
              icon: widget.prefixIcon,
              size: 24,
              color: SharingColors.iconColorDefault,
            ),
            onPressed: () {},
          )
        : widget.prefixIconCustom;
  }

  Widget? showSuffixIcon(BuildContext context) {
    if (widget.isPassword) {
      return IconButton(
        icon: CustomIcon(
          icon: widget.isPasswordVisible
              ? Icons.visibility
              : Icons.visibility_off,
          color: SharingColors.iconColorDefault,
          size: 24,
        ),
        onPressed: () {
          setState(() {
            widget.isPasswordVisible = !widget.isPasswordVisible;
          });
        },
      );
    } else {
      return Row(
        mainAxisSize: MainAxisSize.min,
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          if (widget.hasClearIcon) ...[
            GestureDetector(
                onTap: widget.onClearIconTap, child: widget.clearIcon),
          ],
          if (widget.hasSuffixIcon) ...[
            GestureDetector(
                onTap: widget.onSuffixIconTap, child: widget.suffixIcon),
            SpaceW4()
          ],
        ],
      );
    }
  }
}

==> 0.0.55.tar.gz: lib/widget/custom/custom_text_form_field.dart <==
import 'package:sharing/widget/custom/spaces.dart';

import '../../common/values/borders.dart';
import '../../common/values/colors.dart';
import '../../common/values/sizes.dart';
import '../../common/values/styles.dart';
import 'custom_icon.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

// ignore: must_be_immutable
class CustomTextFormField extends StatefulWidget {
  final TextEditingController controller;
  final FocusNode focusNode;
  final FocusNode? focusNodeNext;
  final TextInputAction textInputAction;
  final TextStyle? hintTextStyle;
  final TextStyle? titleStyle;
  final TextStyle? contentStyle;
  final IconData? prefixIcon;
  final Widget? clearIcon;
  final Widget? prefixIconCustom;
  final Widget? suffixIcon;
  final String? hintText;
  final String? labelText;
  final String? title;
  final bool isPassword;
  final bool hasPrefixIcon;
  final bool hasSuffixIcon;
  final bool hasClearIcon;
  final bool hasTitle;
  final bool hasTitleIcon;
  final Widget? titleIcon;
  final TextInputType textInputType;
  final ValueChanged<String> onChange;
  final Function(String)? onSubmit;
  final FormFieldValidator<String>? validator;
  final List<TextInputFormatter>? inputFormatters;
  final double? width;
  final double? height;
  final EdgeInsetsGeometry? contentPadding;
  final EdgeInsetsGeometry? textFormFieldMargin;
  final Color? backgroundColor;
  final int maxLine;
  final bool hasEmpty;
  final AutovalidateMode autovalidate;
  final bool isBoxShadow;
  final String? textValue;
  final bool? isEnable;
  final int? maxLenght;
  bool isPasswordVisible;
  final GestureTapCallback? onSuffixIconTap;
  final GestureTapCallback? onClearIconTap;

  CustomTextFormField(
      {required this.controller,
      required this.focusNode,
      required this.onChange,
      this.focusNodeNext,
      this.onClearIconTap,
      this.clearIcon,
      this.hasClearIcon = false,
      this.onSubmit,
      this.maxLine = 1,
      this.prefixIcon,
      this.suffixIcon,
      this.hintTextStyle,
      this.titleStyle,
      this.contentStyle,
      this.titleIcon,
      this.hasTitleIcon = false,
      this.title,
      this.contentPadding,
      this.textFormFieldMargin,
      this.hasTitle = false,
      this.hintText,
      this.labelText,
      this.hasPrefixIcon = false,
      this.hasSuffixIcon = false,
      this.isPassword = false,
      this.textInputType = TextInputType.phone,
      this.validator,
      this.inputFormatters,
      this.width,
      this.height,
      this.backgroundColor,
      this.textInputAction = TextInputAction.done,
      this.hasEmpty = false,
      this.isBoxShadow = false,
      this.textValue,
      this.autovalidate = AutovalidateMode.onUserInteraction,
      this.isEnable = true,
      this.maxLenght = 100,
      this.isPasswordVisible = false,
      this.prefixIconCustom,
      this.onSuffixIconTap,});

  @override
  State<CustomTextFormField> createState() => _CustomTextFormFieldState();
}

class _CustomTextFormFieldState extends State<CustomTextFormField> {
  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      mainAxisAlignment: MainAxisAlignment.center,
      mainAxisSize: MainAxisSize.max,
      children: <Widget>[
        Row(
          mainAxisSize: MainAxisSize.max,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: <Widget>[
            if (widget.hasTitleIcon) widget.titleIcon! else Container(),
            widget.hasTitle
                ? Text(widget.title!, style: widget.titleStyle)
                : Container(),
          ],
        ),
        Container(
          width: widget.width,
          height: widget.height,
          decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(Sizes.RADIUS_10),
            boxShadow: showBoxShadow,
          ),
          margin: widget.textFormFieldMargin,
          child: TextFormField(
            showCursor: true,
            textInputAction: widget.textInputAction,
            textAlignVertical: TextAlignVertical.bottom,
            obscureText: isCheckObscureText(),
            maxLength: widget.maxLenght,
            enabled: widget.isEnable,
            controller: widget.controller,
            focusNode: widget.focusNode,
            style: widget.contentStyle ?? Styles.customTextMediumStyle(),
            keyboardType: widget.textInputType,
            onChanged: widget.onChange,
            onFieldSubmitted: (value) {
              if (widget.textInputAction == TextInputAction.next) {
                if (widget.focusNodeNext != null) {
                  FocusScope.of(context).requestFocus(widget.focusNodeNext);
                }
              }
              if (widget.onSubmit != null) {
                widget.onSubmit!(value);
              }
            },
            autovalidateMode: widget.autovalidate,
            validator: widget.validator,
            maxLines: widget.maxLine,
            inputFormatters: widget.inputFormatters,
            decoration: InputDecoration(
              contentPadding: EdgeInsets.only(
                  left: Sizes.PADDING_16,
                  top: Sizes.PADDING_16,
                  bottom: Sizes.PADDING_16,
                  right: -4),
              errorStyle:
                  TextStyle(color: Colors.red, fontSize: Sizes.TEXT_SIZE_16),
              labelText: widget.labelText,
              labelStyle: Styles.customTextDefaultStyle(
                  color: SharingColors.textColor1),
              border: Borders.customOutlineInputBorder(
                  borderRadius: Sizes.RADIUS_8),
              fillColor: widget.backgroundColor ?? Colors.white,
              filled: true,
              enabledBorder: Borders.customOutlineInputBorder(
                  borderRadius: Sizes.RADIUS_8),
              focusedBorder: Borders.customOutlineInputBorder(
                borderRadius: Sizes.RADIUS_8,
                color: SharingColors.secondaryColor,
                width: Sizes.WIDTH_2,
              ),
              prefixIcon: widget.hasPrefixIcon ? showPrefixIcon(context) : null,
              suffixIcon: showSuffixIcon(context),
              hintMaxLines: widget.maxLine,
              hintText: widget.hintText,
              hintStyle: widget.hintTextStyle,
              counterText:
                  widget.textInputType == TextInputType.multiline ? null : "",
            ),
          ),
        ),
      ],
    );
  }

  bool isCheckObscureText() {
    if (widget.isPassword == true) {
      return !widget.isPasswordVisible;
    } else {
      return false;
    }
  }

  List<BoxShadow>? get showBoxShadow {
    if (widget.isBoxShadow) {
      return [
        BoxShadow(
          offset: Offset(0, 2),
          blurRadius: 8.0,
          color: Colors.black.withOpacity(0.2),
        ),
      ];
    } else {
      return null;
    }
  }

  Widget? showPrefixIcon(BuildContext context) {
    return widget.prefixIconCustom == null
        ? IconButton(
            icon: CustomIcon(
              icon: widget.prefixIcon,
              size: 24,
              color: SharingColors.iconColorDefault,
            ),
            onPressed: () {},
          )
        : widget.prefixIconCustom;
  }

  Widget? showSuffixIcon(BuildContext context) {
    if (widget.isPassword) {
      return IconButton(
        icon: CustomIcon(
          icon: widget.isPasswordVisible
              ? Icons.visibility
              : Icons.visibility_off,
          color: SharingColors.iconColorDefault,
          size: 24,
        ),
        onPressed: () {
          setState(() {
            widget.isPasswordVisible = !widget.isPasswordVisible;
          });
        },
      );
    } else {
      return Row(
        mainAxisSize: MainAxisSize.min,
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          if (widget.hasClearIcon) ...[
            GestureDetector(
                onTap: widget.onClearIconTap, child: widget.clearIcon),
          ],
          if (widget.hasSuffixIcon) ...[
            GestureDetector(
                onTap: widget.onSuffixIconTap, child: widget.suffixIcon),
            SpaceW4()
          ],
        ],
      );
    }
  }
}
